/**
 *
 * Copyright (C) 2004, 2005, 2007 by the Gascoigne 3D authors
 *
 * This file is part of Gascoigne 3D
 *
 * Gascoigne 3D is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later
 * version.
 *
 * Gascoigne 3D is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * Please refer to the file LICENSE.TXT for further information
 * on this license.
 *
 **/


#ifndef __local_h
#define __local_h

#include "stokes.h"
#include "problemdescriptorbase.h"
#include "stdloop.h"




using namespace std;
using namespace Gascoigne;


class MyDirichletData : public DirichletData
{
protected:

public:
  MyDirichletData(const ParamFile& pf) : DirichletData(pf){}

  std::string GetName() const
  {
    return "Dirichlet ";
  }
  void operator()(DoubleVector &b, const Vertex2d &v, int color) const
  {
    b.zero();
    // TODO 4.2 implement Dirichlet B.C
  }
};


// class for specifying problem's right hand side
class MyRightHandSide : public DomainRightHandSide
{

  MyData data;

public:

  MyRightHandSide(const MyData& dat) : data(dat)
  {
  }

  MyRightHandSide* createNew() const
  {
    return new MyRightHandSide(data);
  }


  int GetNcomp() const { /*TODO 4.1 set the number of components*/ }
  std::string GetName() const { return "Right Hand Side"; }

  double operator()(int c, const Vertex2d &v) const
  {
    // TODO 4.2 : Implement the right hand side!
    if (c==0) return 0.;
    else return 1.;
   }
};

class ProblemDescriptor : public ProblemDescriptorBase
{
  MyData data;

public:
  std::string GetName() const
  {
    return "Local";
  }


  void BasicInit(const ParamFile& pf)
  {
    data.BasicInit(pf);

    GetParamFile() = pf;
    GetEquationPointer() = new Stokes(data);
    GetRightHandSidePointer() = new MyRightHandSide(data);
    GetDirichletDataPointer() = new MyDirichletData(pf);
    ProblemDescriptorBase::BasicInit(pf);
  }
};


#endif
