#ifndef Stokes_H
#define Stokes_H

#include <paramfile.h>
#include <equation.h>
#include <filescanner.h>

extern double DT;

using namespace Gascoigne;

class MyData
{
public:
  double visc;

  void BasicInit(const ParamFile& pf)
  {
    DataFormatHandler DFH;
    DFH.insert("visc", &visc, 1.);
    
    FileScanner FS(DFH, pf, "Equation");
  }
};


class Stokes : public virtual Equation
{

private:
  MyData data;

public:

  Stokes(const MyData &PD) : data(PD) { }

  Stokes* createNew() const
  {
    return new Stokes(data);
  }

  std::string GetName() const { return "Stokes"; }

  int GetNcomp() const { /*TODO 4.1 set the number of components*/}

  void Form(VectorIterator b,
            const FemFunction &U,
            const TestFunction &N) const;

  void Matrix(EntryMatrix &A,
              const FemFunction &U,
              const TestFunction &M,
              const TestFunction &N) const;

  void point(double h, const FemFunction &U, const Vertex2d &v) const;

};


#endif /* Stokes_H */
